@@ -1,17 +1,17 @@
 ;;; tex-jp.el --- Support for Japanese TeX.
 
 ;; Copyright (C) 1999, 2001 Hidenobu Nabetani <nabe@debian.or.jp>
-;; Copyright (C) 2002, 2003, 2004, 2005 Free Software Foundation
+;; Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007 Free Software Foundation
 
 ;; Author:     KOBAYASHI Shinji <koba@flab.fujitsu.co.jp>
-;; Maintainer: Masayuki Ataka <ataka@milk.freemail.ne.jp>
+;; Maintainer: Masayuki Ataka <masayuki.ataka@gmail.com>
 ;; Keywords: tex
 
 ;; This file is part of AUCTeX.
 
 ;; AUCTeX is free software; you can redistribute it and/or modify it
 ;; under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 2, or (at your option)
+;; the Free Software Foundation; either version 3, or (at your option)
 ;; any later version.
 
 ;; AUCTeX is distributed in the hope that it will be useful, but
@@ -21,8 +21,8 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with AUCTeX; see the file COPYING.  If not, write to the Free
-;; Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-;; 02111-1307, USA.
+;; Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+;; 02110-1301, USA.
 
 ;;; Commentary:
 
@@ -52,13 +52,13 @@
   ;; Changed to double quotes for Windows afflicted people.  I don't
   ;; use the %(latex) and %(tex) shorthands here because I have not
   ;; clue whether Omega-related versions exist.  --dak
-  '(("jTeX" "%(PDF)jtex %S%(PDFout) \"%(mode)\\input %t\""
+  '(("jTeX" "%(PDF)jtex %`%S%(PDFout)%(mode)%' %t"
      TeX-run-TeX nil (plain-tex-mode) :help "Run NTT jTeX")
-    ("jLaTeX" "%(PDF)jlatex %S%(PDFout) \"%(mode)\\input{%t}\""
+    ("jLaTeX" "%(PDF)jlatex %`%S%(PDFout)%(mode)%' %t"
      TeX-run-TeX nil (latex-mode) :help "Run NTT jLaTeX")
-    ("pTeX" "%(PDF)ptex %S%(PDFout) \"%(mode)\\input %t\""
+    ("pTeX" "%(PDF)ptex %`%S%(PDFout)%(mode)%' %t"
      TeX-run-TeX nil (plain-tex-mode) :help "Run ASCII pTeX")
-    ("pLaTeX" "%(PDF)platex %S%(PDFout) \"%(mode)\\input{%t}\""
+    ("pLaTeX" "%(PDF)platex %`%S%(PDFout)%(mode)%' %t"
      TeX-run-TeX nil (latex-mode) :help "Run ASCII pLaTeX")
     ("Mendex" "mendex %s" TeX-run-command nil t :help "Create index file with mendex")
     ("jBibTeX" "jbibtex %s" TeX-run-BibTeX nil t :help "Run jBibTeX"))
@@ -80,7 +80,8 @@ For detail, see `TeX-command-list', which this list is appended to."
 				(function-item TeX-run-discard)
 				(function-item TeX-run-background)
 				(function-item TeX-run-silent)
-				(function-item TeX-run-dviout)
+				(function-item TeX-run-discard-foreground)
+				(function-item TeX-run-function)
 				(function :tag "Other"))
 			(boolean :tag "Prompt")
 			(choice :tag "Modes"
@@ -95,28 +96,32 @@ For detail, see `TeX-command-list', which this list is appended to."
 
 (setq TeX-command-list
       (append japanese-TeX-command-list
-	      '(("-" "" nil nil t)) ;; separator for command menu
+	      '(("-" "" ignore nil t)) ;; separator for command menu
 	      TeX-command-list))
 
-(mapcar (lambda (dir) (add-to-list 'TeX-macro-global dir t))
-  (TeX-macro-global-internal "platex" '("/ptex/" "/jbibtex/bst/")
-    '("/usr/share/texmf/ptex/" "/usr/share/texmf/jbibtex/bst/")))
+(mapc (lambda (dir) (add-to-list 'TeX-macro-global dir t))
+      (or (TeX-tree-expand
+	   '("$SYSTEXMF" "$TEXMFLOCAL" "$TEXMFMAIN" "$TEXMFDIST")
+	   "platex" '("/ptex/" "/jbibtex/bst/"))
+	  '("/usr/share/texmf/ptex/" "/usr/share/texmf/jbibtex/bst/")))
 
-(mapcar (lambda (dir) (add-to-list 'TeX-macro-global dir t))
-  (TeX-macro-global-internal "jlatex" '("/jtex/" "/jbibtex/bst/")
-    '("/usr/share/texmf/jtex/" "/usr/share/texmf/jbibtex/bst/")))
+(mapc (lambda (dir) (add-to-list 'TeX-macro-global dir t))
+      (or (TeX-tree-expand
+	   '("$SYSTEXMF" "$TEXMFLOCAL" "$TEXMFMAIN" "$TEXMFDIST")
+	   "jlatex" '("/jtex/" "/jbibtex/bst/"))
+	  '("/usr/share/texmf/jtex/" "/usr/share/texmf/jbibtex/bst/")))
 
 ;; Menus
 
-(easy-menu-define plain-TeX-mode-command-menu
-  plain-TeX-mode-map
-  "Command menu used in TeX mode."
-  (TeX-mode-specific-command-menu 'plain-tex-mode))
+;; (easy-menu-define plain-TeX-mode-command-menu
+;;   plain-TeX-mode-map
+;;   "Command menu used in TeX mode."
+;;   (TeX-mode-specific-command-menu 'plain-tex-mode))
 
-(easy-menu-define LaTeX-mode-command-menu
-  LaTeX-mode-map
-  "Command menu used in LaTeX mode."
-  (TeX-mode-specific-command-menu 'latex-mode))
+;; (easy-menu-define LaTeX-mode-command-menu
+;;   LaTeX-mode-map
+;;   "Command menu used in LaTeX mode."
+;;   (TeX-mode-specific-command-menu 'latex-mode))
 
 (setq LaTeX-command-style
       (append '(("^j-\\(article\\|report\\|book\\)$"
@@ -132,20 +137,25 @@ For detail, see `TeX-command-list', which this list is appended to."
 
 (when (featurep 'mule)
 
+;; FIX-ME (2007-02-09) The default coding system in recent Unix (like Fedora and
+;; Ubuntu) is utf-8.  But Japanese TeX system is not support utf-8 yet
+;; (platex-utf is under development, may be alpha phase).  So,
+;; process-coding-system for Japanese TeX is not defined from
+;; default-coding-system.  When platex-utf is out, we should look this setting,
+;; again.
+
 (defcustom TeX-japanese-process-input-coding-system
-  (if (boundp 'default-process-coding-system)
-      (cdr default-process-coding-system)
-    ;; Old XEmacs < 21.5?
-    'euc-jp)
+  (cond ((memq system-type '(windows-nt ms-dos cygwin)) 'shift_jis-dos)
+	((memq system-type '(mac darwin)) 'shift_jis-mac)
+	(t 'euc-jp-unix))
   "TeX-process' coding system with standard input."
   :group 'AUCTeX-jp
   :type 'coding-system)
 
 (defcustom TeX-japanese-process-output-coding-system
-  (if (boundp 'default-process-coding-system)
-      (car default-process-coding-system)
-    ;; Old XEmacs < 21.5?
-    'iso-2022-jp)
+  (cond ((memq system-type '(windows-nt ms-dos cygwin)) 'shift_jis-dos)
+	((memq system-type '(mac darwin)) 'shift_jis-mac)
+	(t 'euc-jp-unix))
   "TeX-process' coding system with standard output."
   :group 'AUCTeX-jp
   :type 'coding-system)
@@ -193,24 +203,27 @@ For detail, see `TeX-command-list', which this list is appended to."
 
 (when (featurep 'mule)
 
+(defun japanese-TeX-set-process-coding-system (process)
+  "Set proper coding system for japanese TeX PROCESS."
+  (if (with-current-buffer TeX-command-buffer japanese-TeX-mode)
+      (set-process-coding-system process
+				 TeX-japanese-process-output-coding-system
+				 TeX-japanese-process-input-coding-system)))
 (setq TeX-after-start-process-function
-      (lambda (process)
-	(set-process-coding-system process
-	 TeX-japanese-process-output-coding-system
-	 TeX-japanese-process-input-coding-system)))
+      'japanese-TeX-set-process-coding-system)
 )
 
 ;;; Japanese TeX modes
 
 (defvar japanese-TeX-mode nil
-  "Flag to determine if the current buffer is Japanese TeX/LaTeX.")
+  "Non-nil means the current buffer handles Japanese TeX/LaTeX.")
 (make-variable-buffer-local 'japanese-TeX-mode)
 (put 'japanese-TeX-mode 'permanent-local t)
 
 ;;;###autoload
 (defun japanese-plain-tex-mode ()
   "Major mode in AUCTeX for editing Japanese plain TeX files.
-Set japanese-TeX-mode to t, and enters plain-tex-mode."
+Set `japanese-TeX-mode' to t, and enter `TeX-plain-tex-mode'."
   (interactive)
   (setq japanese-TeX-mode t)
   (TeX-plain-tex-mode))
@@ -225,7 +238,7 @@ Set japanese-TeX-mode to t, and enters plain-tex-mode."
 ;;;###autoload
 (defun japanese-latex-mode ()
   "Major mode in AUCTeX for editing Japanese LaTeX files.
-Set japanese-TeX-mode to t, and enters latex-mode."
+Set `japanese-TeX-mode' to t, and enter `TeX-latex-mode'."
   (interactive)
   (setq japanese-TeX-mode t)
   (TeX-latex-mode))
@@ -242,21 +255,23 @@ Set japanese-TeX-mode to t, and enters latex-mode."
 
 ;;; Support for various self-insert-command
 
-(cond ((fboundp 'can-n-egg-self-insert-command)
-       (fset 'tex-jp-self-insert-command 'can-n-egg-self-insert-command))
-      ((fboundp 'egg-self-insert-command)
-       (fset 'tex-jp-self-insert-command 'egg-self-insert-command))
-      ((fboundp 'canna-self-insert-command)
-       (fset 'tex-jp-self-insert-command 'canna-self-insert-command))
-      (t
-       (fset 'tex-jp-self-insert-command 'self-insert-command)))
+(fset 'japanese-TeX-self-insert-command
+      (cond ((fboundp 'can-n-egg-self-insert-command)
+	     'can-n-egg-self-insert-command)
+	    ((fboundp 'egg-self-insert-command)
+	     'egg-self-insert-command)
+	    ((fboundp 'canna-self-insert-command)
+	     'canna-self-insert-command)
+	    (t
+	     'self-insert-command)))
 
 (defun TeX-insert-punctuation ()
   "Insert point or comma, cleaning up preceding space."
   (interactive)
+  (expand-abbrev)
   (if (TeX-looking-at-backward "\\\\/\\(}+\\)" 50)
       (replace-match "\\1" t))
-  (call-interactively 'tex-jp-self-insert-command))
+  (call-interactively 'japanese-TeX-self-insert-command))
 
 ;;; Error Messages
 
@@ -267,7 +282,7 @@ Set japanese-TeX-mode to t, and enters latex-mode."
 
     ("Bad math environment delimiter.*" .
 "$B?t<0%b!<%ICf$G?t<0%b!<%I3+;O%3%^%s%I(B\\[$B$^$?$O(B\\($B!$$^$?$O!$?t<0%b!<%I30$G(B
-$B?t<0%b!<%I=*N;%3%^%s%I(B\\[$B$^$?$O(B\\($B$r(BTeX$B$,8+$D$1$^$7$?!%$3$NLdBj$O!$?t<0%b!<(B
+$B?t<0%b!<%I=*N;%3%^%s%I(B\\]$B$^$?$O(B\\)$B$r(BTeX$B$,8+$D$1$^$7$?!%$3$NLdBj$O!$?t<0%b!<(B
 $B%I$N%G%j%_%?$,%^%C%A$7$F$$$J$+$C$?$j!$3g8L$N%P%i%s%9$,$H$l$F$$$J$+$C$?$j$9(B
 $B$k$?$a$K@8$8$^$9!%(B")
 
@@ -282,7 +297,7 @@ Set japanese-TeX-mode to t, and enters latex-mode."
 $B$l$+$G$7$g$&!%(B")
 
     ("Can be used only in preamble." .
-"$B%W%j%"%s%V%k$G$7$+;H$($J$$(B\\documentstyle$B!&(B\\nofiles$B!&(B\\includeonly
+"$B%W%j%"%s%V%k$G$7$+;H$($J$$(B\\documentclass$B!&(B\\nofiles$B!&(B\\includeonly
 \\makeindex$B!&(B\\makeglossary$B$N$&$A$N$$$:$l$+$,(B\\begin{document}$B$h$j$b(B
 $B8e$G;H$o$l$F$$$k$N$r(BLaTeX$B$,8!=P$7$^$7$?!%$3$N%(%i!<$O(B\\begin{document}
 $B$,M>J,$K$"$C$?;~$K$b@8$8$^$9!%(B")
@@ -296,9 +311,13 @@ Set japanese-TeX-mode to t, and enters latex-mode."
 \\renew...$BL?Na$r;H$o$J$1$l$P$J$j$^$;$s!%(B")
 
     ("Counter too large." .
-"$BJ8;z$G=g=xIU$1$5$l$?$b$N!$$?$V$sHV9fIU$1$5$l$?%j%9%H4D6-$N%i%Y%k$,!$(B
+"1. $BJ8;z$G=g=xIU$1$5$l$?$b$N!$$?$V$sHV9fIU$1$5$l$?%j%9%H4D6-$N%i%Y%k$,!$(B
 26$B$h$j$bBg$-$$HV9f$r<u$1<h$j$^$7$?!%Hs>o$KD9$$%j%9%H$r;H$C$F$$$k$+!$(B
-$B%+%&%s%?$r:F@_Dj$7$F$7$^$C$?$+$N$$$:$l$+$G$7$g$&!%(B")
+$B%+%&%s%?$r:F@_Dj$7$F$7$^$C$?$+$N$$$:$l$+$G$7$g$&!%(B
+
+2. $B5SCm$,J8;z$^$?$O5SCm5-9f$G=g=x$E$1$5$l$F$$$^$9$,!$J8;z$^$?$O5-9f$r(B
+$B;H$$@Z$C$F$7$^$$$^$7$?!%$*$=$i$/(B\\thanks$BL?Na$N;H$$$9$.$G$9!%(B")
+
 
     ("Environment [^ ]* undefined." .
 "$BDj5A$5$l$F$$$J$$4D6-$KBP$9$k(B\\begin$BL?Na$r(BLaTeX$B$,8+$D$1$^$7$?!%$*$=$i$/(B
@@ -388,10 +407,6 @@ thebibliography$B4D6-$G0z?t$rK:$l$?>l9g$K$b@8$8$^$9!%(B")
 "\\<$BL?Na$,(Btabbing$B4D6-$N9T$NESCf$K8=$l$^$7$?!%$3$NL?Na$O9T$N@hF,$K$J$1$l$P(B
 $B$J$j$^$;$s!%(B")
 
-    ("Counter too large." .
-"$B5SCm$,J8;z$^$?$O5SCm5-9f$G=g=x$E$1$5$l$F$$$^$9$,!$J8;z$^$?$O5-9f$r;H$$(B
-$B@Z$C$F$7$^$$$^$7$?!%$*$=$i$/(B\\thanks$BL?Na$N;H$$$9$.$G$9!%(B")
-
     ("Double subscript." .
 "$B?t<0Cf$N(B1$B$D$NNs$K(B2$B$D$N2<IU$-J8;z$,$D$$$F$$$^$9!%Nc$($P(Bx_{2}_{3}$B$N$h$&$K!%(B
 $B$3$N$h$&$JI=8=$OL50UL#$G$9!%(B")
@@ -543,7 +558,7 @@ main memory size
 $B$k!%(B(3)$B@8@.$N$?$a$N>pJs$r(BTeX$B$,J];}$7$-$l$J$$$h$&$J!$$"$^$j$K$bJ#;($J%Z!<(B
 $B%8$r@8@.$7$h$&$H$7$?!%:G=i$N(B2$B$D$NLdBj$N2r7hJ}K!$OL@$i$+$G$9!%L?NaDj5A(B
 $B$N?t$"$k$$$O(B\\index$B!&(B\\glossary$BL?Na$N?t$r8:$i$9$3$H$G$9!%(B3$BHVL\$NLdBj$O(B
-$B$A$g$C$HLq2p$G$9!%$3$l$O!$Bg$-$J(Btabbin$B!&(Btabular$B!&(Barray$B!&(Bpicture$B4D6-$N(B
+$B$A$g$C$HLq2p$G$9!%$3$l$O!$Bg$-$J(Btabbing$B!&(Btabular$B!&(Barray$B!&(Bpicture$B4D6-$N(B
 $B$;$$$G@8$8$k$3$H$,$"$j$^$9!%=PNO0LCV$,7hDj$5$l$k$N$rBT$C$F$$$k?^$dI=$G(B
 TeX$B$N%a%b%j$,$$$C$Q$$$K$J$C$F$$$k$N$+$b$7$l$^$;$s!%K\Ev$K(BTeX$B$NMFNL$rD6(B
 $B$($F$7$^$C$?$N$+$I$&$+D4$Y$k$?$a$K$O!$%(%i!<$N5/$3$C$?>l=j$ND>A0$K(B
@@ -584,7 +599,7 @@ save size
 "TeX$B$,L$Dj5A$NL?NaL>$rH/8+$7$^$7$?!%$*$=$i$/F~NO$N8m$j$G$7$g$&!%$b$7$3(B
 $B$N%(%i!<$,(BLaTeX$BL?Na$N=hM}Cf$K@8$8$?>l9g$O!$$=$NL?Na$O4V0c$C$?0LCV$KCV$+(B
 $B$l$F$$$^$9!%Nc$($P!$%j%9%H4D6-$NCf$G$J$$$N$K(B\\item$BL?Na$,;H$o$l$?>l9g$J$I(B
-$B$G$9!%$^$?!$(B\\documentstyle$BL?Na$,$J$$>l9g$K$b$3$N%(%i!<$,@8$8$^$9!%(B")
+$B$G$9!%$^$?!$(B\\documentclass$BL?Na$,$J$$>l9g$K$b$3$N%(%i!<$,@8$8$^$9!%(B")
 
     ("Use of [^ ]* doesn't match its definition." .
 "$B$*$=$i$/IA2h$N$?$a$NL?Na$@$H;W$o$l$^$9$,!$0z?t$N;H$$$+$?$,4V0c$C$F$$(B
